@@ -18,11 +18,10 @@ class fitter(object):
     # Define possible fit functions for given run modes
     function_names = {  '20':('Exp','Bi Exp','Str Exp'),
                         '2h':('Exp','Bi Exp','Str Exp'),
-                        '1f':('Lorentzian','Gaussian','BiLorentzian',),
+                        '1f':('Lorentzian','Gaussian','BiLorentzian','QuadLorentz'),
                         '1w':('Lorentzian','Gaussian','BiLorentzian',),
                         '1n':('Lorentzian','Gaussian','BiLorentzian',),
-                        '1e':('Lorentzian','Gaussian','BiLorentzian',),
-                        '2e':('Lorentzian','Gaussian','BiLorentzian',)}
+                        '2e':('Lorentzian','Gaussian','BiLorentzian','QuadLorentz')}
      
     # Define names of fit parameters:
     param_names = {     'Exp'       :('1_T1','amp'),
@@ -31,6 +30,9 @@ class fitter(object):
                         'Lorentzian':('peak','width','height','baseline'),
                         'BiLorentzian':('peak','widthA','heightA',
                                                'widthB','heightB','baseline'),
+                        'QuadLorentz':('nu_0', 'nu_q', 'efgAsym', 'efgTheta', 'efgPhi', 
+	                               'amp0', 'amp1', 'amp2', 'amp3', 'fwhm',
+                                       'baseline'),
                         'Gaussian'  :('mean','sigma','height','baseline'),}
 
     # dictionary of initial parameters
@@ -40,6 +42,10 @@ class fitter(object):
 
     # define list of ok run modes 
     valid_asym_modes = ('c','p','n','sl_c','dif_c',)
+    
+    # probe species spin numbers
+    spin = {'Li8':2,
+            'Mg31':0.5}
 
     # ======================================================================= #
     def __init__(self,keyfn, probe_species='Li8'):
@@ -75,7 +81,7 @@ class fitter(object):
                                  
             hist_select: string for selection of histograms
             asym_mode:  input for asymmetry calculation type 
-                            c: combined helicity
+                                               c: combined helicity
                             h: split helicity
                             p: positive helicity
                             n: negative helicity
@@ -282,14 +288,14 @@ class fitter(object):
                 amp_bounds = (0,np.inf)
             
             # set values
-            par_values = {'amp':(amp,*amp_bounds),
-                          '1_T1':(1./T1,0,np.inf),
-                          '1_T1b':(10./T1,0,np.inf),
-                          'fraction_b':(0.5,0,1),
-                          'beta':(0.5,0,1)}
+            par_values = {'amp':(amp,*amp_bounds,False),
+                          '1_T1':(1./T1,0,np.inf,False),
+                          '1_T1b':(10./T1,0,np.inf,False),
+                          'fraction_b':(0.5,0,1,False),
+                          'beta':(0.5,0,1,False)}
                          
         # set time integrated fit initial parameters
-        elif fn_name in ('Lorentzian','Gaussian','BiLorentzian'):
+        elif fn_name in ('Lorentzian','Gaussian','BiLorentzian','QuadLorentz'):
             
             # get peak asym value
             amin = min(a[a!=0])
@@ -305,27 +311,43 @@ class fitter(object):
             else:
                 height_bounds = (0,np.inf)
             
-            # set values
-            if fn_name == 'Lorentzian':
-                par_values = {'peak':(peak,min(x),max(x)),
-                              'width':(width,0,np.inf),
-                              'height':(height,*height_bounds),
-                              'baseline':(base,-np.inf,np.inf)
+            # set values (value, low bnd, high bnd, fixed)
+            if fn_name == 'Lorentzian':	
+                par_values = {'peak':(peak,min(x),max(x),False),
+                              'width':(width,0,np.inf,False),
+                              'height':(height,*height_bounds,False),
+                              'baseline':(base,-np.inf,np.inf,False)
                              }
             elif fn_name == 'Gaussian':
-                par_values = {'mean':(peak,min(x),max(x)),
-                              'sigma':(width,0,np.inf),
-                              'height':(height,*height_bounds),
-                              'baseline':(base,-np.inf,np.inf)
+                par_values = {'mean':(peak,min(x),max(x),False),
+                              'sigma':(width,0,np.inf,False),
+                              'height':(height,*height_bounds,False),
+                              'baseline':(base,-np.inf,np.inf,False)
                               }
-            if fn_name == 'BiLorentzian':
-                par_values = {'peak':(peak,min(x),max(x)),
-                              'widthA':(width,0,np.inf),
-                              'heightA':(height,*height_bounds),
-                              'widthB':(width,0,np.inf),
-                              'heightB':(height,*height_bounds),
-                              'baseline':(base,-np.inf,np.inf)
+            elif fn_name == 'BiLorentzian':
+                par_values = {'peak':(peak,min(x),max(x),False),
+                              'widthA':(width,0,np.inf,False),
+                              'heightA':(height,*height_bounds,False),
+                              'widthB':(width,0,np.inf,False),
+                              'heightB':(height,*height_bounds,False),
+                              'baseline':(base,-np.inf,np.inf,False)
                              }
+            elif fn_name == 'QuadLorentz':
+                
+                dx = max(x)-min(x)
+                par_values = {'nu_0':((max(x)+min(x))/2,min(x),max(x),False),
+                              'nu_q':(dx/12,0,dx,False),
+                              'efgAsym':(0,0,1,True),
+                              'efgTheta':(0,0,2*np.pi,True),
+                              'efgPhi':(0,0,2*np.pi,True),
+                              'amp0':(height,height*0.1,np.inf,False), 
+                              'amp1':(height,height*0.1,np.inf,False), 
+                              'amp2':(height,height*0.1,np.inf,False), 
+                              'amp3':(height,height*0.1,np.inf,False), 
+                              'fwhm':(dx/10,0,dx,False),
+                              'baseline':(base,-np.inf,np.inf,False)
+                             }
+         
         else:
             raise RuntimeError('Bad function name.')
         
@@ -363,6 +385,14 @@ class fitter(object):
         elif fn_name == 'BiLorentzian':
             fn =  fns.bilorentzian
             self.mode=1
+        elif fn_name == 'QuadLorentz':
+            fn =  lambda freq, nu_0, nu_q, eta, theta, phi, \
+            		amp0, amp1, amp2, amp3, fwhm: \
+                   	fns.quadlorentzian(freq, nu_0, nu_q, eta, theta, phi, \
+		            		amp0, amp1, amp2, amp3, \
+                		   	fwhm, fwhm, fwhm, fwhm, \
+                		   	I=self.spin[self.probe_species])
+            self.mode=1
         elif fn_name == 'Gaussian':
             fn =  fns.gaussian
             self.mode=1
